@@ -61,7 +61,7 @@ class GPGTool(Command):
 	gui = None
 	frc = None
 	iac = None
-	sig = None
+	sig = True
 	dtg = True
 	__c = 0
 	__ppw = None
@@ -143,10 +143,8 @@ class GPGTool(Command):
 	def _gpg_(self):
 		"""gpg wrapper property"""
 		opts = ['--batch']
-		if osname != 'nt' and not self.gui:
+		if osname != 'nt':
 			opts = ['--pinentry-mode=loopback']
-		if self.__c == 0 or not self._gpgselfcheck:
-			self._gpgcheck()
 		if self.__c >= 1 and not self.__ppw:
 			self.__ppw = self.passwd(False, self.gui, self.pwdmsg)
 		__g = GPG(
@@ -329,21 +327,22 @@ class GPGTool(Command):
 			recvs = [gpgkey]
 		self.sh_ = True
 		getin = input
-		quest = '%s [Y/n]'%grn('could not authenticate, retry?')
-		cmd = '%s -d --always-trust --pinentry-mode=loopback'%self.binary
+		quest = '%s [y/n]'%grn('could not authenticate, retry?')
+		cmd = '%s --batch --always-trust'%self.binary
 		if self.gui:
 			getin = xyesno
 			quest = 'could not authenticate, retry?'
-			cmd = '%s -d --always-trust'%self.binary
 		enc = self.stdo(
-            'gpg -e -r %s'%' -r '.join(k for k in recvs), inputs='')
-		rtn = self.call(cmd, inputs=enc.encode(), stderr=False)
+            '%s %s -e'%(cmd, ' -r '.join(k for k in recvs)), inputs='')
+		rtn = self.call('%s -d'%cmd, inputs=enc.encode(), stderr=False)
 		if rtn == 0:
 			self._gpgselfcheck = True
 			return True
 		yesno = getin(quest)
-		if str(yesno) in ('true', 'y', ''):
-			return self._gpgcheck()
+		if str(yesno) not in ('true', 'y'):
+			self.__c += 1
+			return
+		return self._gpgcheck()
 
 	def recvlist(self, crypt):
 		keys = []
