@@ -1,10 +1,18 @@
 """system lib init for pwclip"""
+from system.android import adbout, adbenter
+
 from system.clips import clips, copy, paste
 
 from system.user import userfind, whoami
 
 from system.path import absrelpath, filetime, setfiletime, filerotate
 
-from system.xlib import xinput, xnotify, xyesno, xmsgok, xgetpass
+from system.random import randin, random
 
 from system.which import which
+
+from system.dictreplace import dictreplace
+
+from system.envconf import envconf
+
+from system.xlib import xinput, xnotify, xyesno, xmsgok, xgetpass, xkbid
